@@ -10,4 +10,4 @@ Field = Union[graphql.GraphQLField, graphql.GraphQLInputField]
 InterfaceOrObject = Union[graphql.GraphQLObjectType, graphql.GraphQLInterfaceType]
 SelectionNodes = List[graphql.SelectionNode]
 AstPrinter = Callable[[graphql.Node], str]
-CustomScalars = Dict[str, st.SearchStrategy[graphql.ValueNode]]
+CustomScalarStrategies = Dict[str, st.SearchStrategy[graphql.ValueNode]]
